EXPORTS
	?ChannelVolumeL@CMidiClientUtility@@QBEMH@Z @ 1 NONAME ; public: float __thiscall CMidiClientUtility::ChannelVolumeL(int)const 
	?ChannelsSupportedL@CMidiClientUtility@@QBEHXZ @ 2 NONAME ; public: int __thiscall CMidiClientUtility::ChannelsSupportedL(void)const 
	?Close@CMidiClientUtility@@QAEXXZ @ 3 NONAME ; public: void __thiscall CMidiClientUtility::Close(void)
	?CustomBankLoadedL@CMidiClientUtility@@QBEHH@Z @ 4 NONAME ; public: int __thiscall CMidiClientUtility::CustomBankLoadedL(int)const 
	?CustomCommandAsync@CMidiClientUtility@@QAEXABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1AAVTDes8@@AAVTRequestStatus@@@Z @ 5 NONAME ; public: void __thiscall CMidiClientUtility::CustomCommandAsync(class TPckgBuf<class TMMFMessageDestination> const &,int,class TDesC8 const &,class TDesC8 const &,class TDes8 &,class TRequestStatus &)
	?CustomCommandAsync@CMidiClientUtility@@QAEXABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1AAVTRequestStatus@@@Z @ 6 NONAME ; public: void __thiscall CMidiClientUtility::CustomCommandAsync(class TPckgBuf<class TMMFMessageDestination> const &,int,class TDesC8 const &,class TDesC8 const &,class TRequestStatus &)
	?CustomCommandSyncL@CMidiClientUtility@@QAEXABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1@Z @ 7 NONAME ; public: void __thiscall CMidiClientUtility::CustomCommandSyncL(class TPckgBuf<class TMMFMessageDestination> const &,int,class TDesC8 const &,class TDesC8 const &)
	?CustomCommandSyncL@CMidiClientUtility@@QAEXABV?$TPckgBuf@VTMMFMessageDestination@@@@HABVTDesC8@@1AAVTDes8@@@Z @ 8 NONAME ; public: void __thiscall CMidiClientUtility::CustomCommandSyncL(class TPckgBuf<class TMMFMessageDestination> const &,int,class TDesC8 const &,class TDesC8 const &,class TDes8 &)
	?DurationMicroBeatsL@CMidiClientUtility@@QBE_JXZ @ 9 NONAME ; public: long long  __thiscall CMidiClientUtility::DurationMicroBeatsL(void)const 
	?DurationMicroSecondsL@CMidiClientUtility@@QBE?AVTTimeIntervalMicroSeconds@@XZ @ 10 NONAME ; public: class TTimeIntervalMicroSeconds  __thiscall CMidiClientUtility::DurationMicroSecondsL(void)const 
	?GetBalanceL@CMidiClientUtility@@QBEHXZ @ 11 NONAME ; public: int __thiscall CMidiClientUtility::GetBalanceL(void)const 
	?GetBankIdL@CMidiClientUtility@@QBEHHH@Z @ 12 NONAME ; public: int __thiscall CMidiClientUtility::GetBankIdL(int,int)const 
	?GetInstrumentIdL@CMidiClientUtility@@QBEHHHH@Z @ 13 NONAME ; public: int __thiscall CMidiClientUtility::GetInstrumentIdL(int,int,int)const 
	?GetInstrumentL@CMidiClientUtility@@QAEXHAAH0@Z @ 14 NONAME ; public: void __thiscall CMidiClientUtility::GetInstrumentL(int,int &,int &)
	?GetMetaDataEntryL@CMidiClientUtility@@QBEPAVCMMFMetaDataEntry@@H@Z @ 15 NONAME ; public: class CMMFMetaDataEntry * __thiscall CMidiClientUtility::GetMetaDataEntryL(int)const 
	?GetRepeats@CMidiClientUtility@@QBEHXZ @ 16 NONAME ; public: int __thiscall CMidiClientUtility::GetRepeats(void)const 
	?InstrumentNameL@CMidiClientUtility@@QBEPAVHBufC16@@HHH@Z @ 17 NONAME ; public: class HBufC16 * __thiscall CMidiClientUtility::InstrumentNameL(int,int,int)const 
	?IsChannelMuteL@CMidiClientUtility@@QBEHH@Z @ 18 NONAME ; public: int __thiscall CMidiClientUtility::IsChannelMuteL(int)const 
	?IsTrackMuteL@CMidiClientUtility@@QBEHH@Z @ 19 NONAME ; public: int __thiscall CMidiClientUtility::IsTrackMuteL(int)const 
	?LoadCustomBankDataL@CMidiClientUtility@@QAEXABVTDesC8@@AAH@Z @ 20 NONAME ; public: void __thiscall CMidiClientUtility::LoadCustomBankDataL(class TDesC8 const &,int &)
	?LoadCustomBankL@CMidiClientUtility@@QAEXABVTDesC16@@AAH@Z @ 21 NONAME ; public: void __thiscall CMidiClientUtility::LoadCustomBankL(class TDesC16 const &,int &)
	?LoadCustomInstrumentDataL@CMidiClientUtility@@QAEXABVTDesC8@@HHHH@Z @ 22 NONAME ; public: void __thiscall CMidiClientUtility::LoadCustomInstrumentDataL(class TDesC8 const &,int,int,int,int)
	?LoadCustomInstrumentL@CMidiClientUtility@@QAEXABVTDesC16@@HHHH@Z @ 23 NONAME ; public: void __thiscall CMidiClientUtility::LoadCustomInstrumentL(class TDesC16 const &,int,int,int,int)
	?MaxChannelVolumeL@CMidiClientUtility@@QBEMXZ @ 24 NONAME ; public: float __thiscall CMidiClientUtility::MaxChannelVolumeL(void)const 
	?MaxPlaybackRateL@CMidiClientUtility@@QBEHXZ @ 25 NONAME ; public: int __thiscall CMidiClientUtility::MaxPlaybackRateL(void)const 
	?MaxVolumeL@CMidiClientUtility@@QBEHXZ @ 26 NONAME ; public: int __thiscall CMidiClientUtility::MaxVolumeL(void)const 
	?MimeTypeL@CMidiClientUtility@@QAEABVTDesC8@@XZ @ 27 NONAME ; public: class TDesC8 const & __thiscall CMidiClientUtility::MimeTypeL(void)
	?MinPlaybackRateL@CMidiClientUtility@@QBEHXZ @ 28 NONAME ; public: int __thiscall CMidiClientUtility::MinPlaybackRateL(void)const 
  ?NewL@CMidiClientUtility@@SAPAV1@AAVMMidiClientUtilityObserver@@HH@Z @ 29 NONAME ; class CMidiClientUtility * CMidiClientUtility::NewL(class MMidiClientUtilityObserver &, int, int)
	?NoteOffL@CMidiClientUtility@@QAEXHHH@Z @ 30 NONAME ; public: void __thiscall CMidiClientUtility::NoteOffL(int,int,int)
	?NoteOnL@CMidiClientUtility@@QAEXHHH@Z @ 31 NONAME ; public: void __thiscall CMidiClientUtility::NoteOnL(int,int,int)
	?NumTracksL@CMidiClientUtility@@QBEHXZ @ 32 NONAME ; public: int __thiscall CMidiClientUtility::NumTracksL(void)const 
	?NumberOfBanksL@CMidiClientUtility@@QBEHH@Z @ 33 NONAME ; public: int __thiscall CMidiClientUtility::NumberOfBanksL(int)const 
	?NumberOfInstrumentsL@CMidiClientUtility@@QBEHHH@Z @ 34 NONAME ; public: int __thiscall CMidiClientUtility::NumberOfInstrumentsL(int,int)const 
	?NumberOfMetaDataEntriesL@CMidiClientUtility@@QBEHXZ @ 35 NONAME ; public: int __thiscall CMidiClientUtility::NumberOfMetaDataEntriesL(void)const 
	?OpenDes@CMidiClientUtility@@QAEXABVTDesC8@@@Z @ 36 NONAME ; public: void __thiscall CMidiClientUtility::OpenDes(class TDesC8 const &)
	?OpenFile@CMidiClientUtility@@QAEXABVTDesC16@@@Z @ 37 NONAME ; public: void __thiscall CMidiClientUtility::OpenFile(class TDesC16 const &)
	?OpenUrl@CMidiClientUtility@@QAEXABVTDesC16@@HABVTDesC8@@@Z @ 38 NONAME ; public: void __thiscall CMidiClientUtility::OpenUrl(class TDesC16 const &,int,class TDesC8 const &)
	?PercussionKeyNameL@CMidiClientUtility@@QBEPAVHBufC16@@HHHH@Z @ 39 NONAME ; public: class HBufC16 * __thiscall CMidiClientUtility::PercussionKeyNameL(int,int,int,int)const 
	?PitchTranspositionCentsL@CMidiClientUtility@@QBEHXZ @ 40 NONAME ; public: int __thiscall CMidiClientUtility::PitchTranspositionCentsL(void)const 
	?Play@CMidiClientUtility@@QAEXXZ @ 41 NONAME ; public: void __thiscall CMidiClientUtility::Play(void)
	?PlayNoteL@CMidiClientUtility@@QAEXHHABVTTimeIntervalMicroSeconds@@0HH@Z @ 42 NONAME ; public: void __thiscall CMidiClientUtility::PlayNoteL(int,int,class TTimeIntervalMicroSeconds const &,class TTimeIntervalMicroSeconds const &,int,int)
	?PlayNoteL@CMidiClientUtility@@QAEXHHABVTTimeIntervalMicroSeconds@@HH@Z @ 43 NONAME ; public: void __thiscall CMidiClientUtility::PlayNoteL(int,int,class TTimeIntervalMicroSeconds const &,int,int)
	?PlaybackRateL@CMidiClientUtility@@QBEHXZ @ 44 NONAME ; public: int __thiscall CMidiClientUtility::PlaybackRateL(void)const 
	?PolyphonyL@CMidiClientUtility@@QBEHXZ @ 45 NONAME ; public: int __thiscall CMidiClientUtility::PolyphonyL(void)const 
	?PositionMicroBeatsL@CMidiClientUtility@@QBE_JXZ @ 46 NONAME ; public: long long  __thiscall CMidiClientUtility::PositionMicroBeatsL(void)const 
	?PositionMicroSecondsL@CMidiClientUtility@@QBE?AVTTimeIntervalMicroSeconds@@XZ @ 47 NONAME ; public: class TTimeIntervalMicroSeconds  __thiscall CMidiClientUtility::PositionMicroSecondsL(void)const 
	?SendMessageL@CMidiClientUtility@@QAEHABVTDesC8@@@Z @ 48 NONAME ; public: int __thiscall CMidiClientUtility::SendMessageL(class TDesC8 const &)
	?SendMessageL@CMidiClientUtility@@QAEHABVTDesC8@@ABVTTimeIntervalMicroSeconds@@@Z @ 49 NONAME ; public: int __thiscall CMidiClientUtility::SendMessageL(class TDesC8 const &,class TTimeIntervalMicroSeconds const &)
	?SendMipMessageL@CMidiClientUtility@@QAEXABV?$RArray@VTMipMessageEntry@@@@@Z @ 50 NONAME ; public: void __thiscall CMidiClientUtility::SendMipMessageL(class RArray<class TMipMessageEntry> const &)
	?SetBalanceL@CMidiClientUtility@@QAEXH@Z @ 51 NONAME ; public: void __thiscall CMidiClientUtility::SetBalanceL(int)
	?SetBankL@CMidiClientUtility@@QAEXH@Z @ 52 NONAME ; public: void __thiscall CMidiClientUtility::SetBankL(int)
	?SetChannelMuteL@CMidiClientUtility@@QAEXHH@Z @ 53 NONAME ; public: void __thiscall CMidiClientUtility::SetChannelMuteL(int,int)
	?SetChannelVolumeL@CMidiClientUtility@@QAEXHM@Z @ 54 NONAME ; public: void __thiscall CMidiClientUtility::SetChannelVolumeL(int,float)
	?SetInstrumentL@CMidiClientUtility@@QAEXHHH@Z @ 55 NONAME ; public: void __thiscall CMidiClientUtility::SetInstrumentL(int,int,int)
	?SetMaxPolyphonyL@CMidiClientUtility@@QAEXH@Z @ 56 NONAME ; public: void __thiscall CMidiClientUtility::SetMaxPolyphonyL(int)
	?SetPitchTranspositionL@CMidiClientUtility@@QAEHH@Z @ 57 NONAME ; public: int __thiscall CMidiClientUtility::SetPitchTranspositionL(int)
	?SetPlaybackRateL@CMidiClientUtility@@QAEXH@Z @ 58 NONAME ; public: void __thiscall CMidiClientUtility::SetPlaybackRateL(int)
	?SetPositionMicroBeatsL@CMidiClientUtility@@QAEX_J@Z @ 59 NONAME ; public: void __thiscall CMidiClientUtility::SetPositionMicroBeatsL(long long)
	?SetPositionMicroSecondsL@CMidiClientUtility@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 60 NONAME ; public: void __thiscall CMidiClientUtility::SetPositionMicroSecondsL(class TTimeIntervalMicroSeconds const &)
	?SetPriorityL@CMidiClientUtility@@QAEXHH@Z @ 61 NONAME ; void CMidiClientUtility::SetPriorityL(int, int)
	?SetRepeatsL@CMidiClientUtility@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 62 NONAME ; public: void __thiscall CMidiClientUtility::SetRepeatsL(int,class TTimeIntervalMicroSeconds const &)
	?SetStopTimeL@CMidiClientUtility@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 63 NONAME ; public: void __thiscall CMidiClientUtility::SetStopTimeL(class TTimeIntervalMicroSeconds const &)
	?SetSyncUpdateCallbackIntervalL@CMidiClientUtility@@QAEXABVTTimeIntervalMicroSeconds@@_J@Z @ 64 NONAME ; public: void __thiscall CMidiClientUtility::SetSyncUpdateCallbackIntervalL(class TTimeIntervalMicroSeconds const &,long long)
	?SetTempoL@CMidiClientUtility@@QAEXH@Z @ 65 NONAME ; public: void __thiscall CMidiClientUtility::SetTempoL(int)
	?SetTrackMuteL@CMidiClientUtility@@QBEXHH@Z @ 66 NONAME ; public: void __thiscall CMidiClientUtility::SetTrackMuteL(int,int)const 
	?SetVolumeL@CMidiClientUtility@@QAEXH@Z @ 67 NONAME ; public: void __thiscall CMidiClientUtility::SetVolumeL(int)
	?SetVolumeRampL@CMidiClientUtility@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 68 NONAME ; public: void __thiscall CMidiClientUtility::SetVolumeRampL(class TTimeIntervalMicroSeconds const &)
	?State@CMidiClientUtility@@QBE?AW4TMidiState@@XZ @ 69 NONAME ; public: enum TMidiState  __thiscall CMidiClientUtility::State(void)const 
	?Stop@CMidiClientUtility@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 70 NONAME ; public: void __thiscall CMidiClientUtility::Stop(class TTimeIntervalMicroSeconds const &)
	?StopNotes@CMidiClientUtility@@QAEXH@Z @ 71 NONAME ; public: void __thiscall CMidiClientUtility::StopNotes(int)
	?StopTimeL@CMidiClientUtility@@QBEXAAVTTimeIntervalMicroSeconds@@@Z @ 72 NONAME ; public: void __thiscall CMidiClientUtility::StopTimeL(class TTimeIntervalMicroSeconds &)const 
	?TempoMicroBeatsPerMinuteL@CMidiClientUtility@@QBEHXZ @ 73 NONAME ; public: int __thiscall CMidiClientUtility::TempoMicroBeatsPerMinuteL(void)const 
	?UnloadAllCustomBanksL@CMidiClientUtility@@QAEXXZ @ 74 NONAME ; public: void __thiscall CMidiClientUtility::UnloadAllCustomBanksL(void)
	?UnloadCustomBankL@CMidiClientUtility@@QAEXH@Z @ 75 NONAME ; public: void __thiscall CMidiClientUtility::UnloadCustomBankL(int)
	?UnloadCustomInstrumentL@CMidiClientUtility@@QAEXHH@Z @ 76 NONAME ; public: void __thiscall CMidiClientUtility::UnloadCustomInstrumentL(int,int)
	?VolumeL@CMidiClientUtility@@QBEHXZ @ 77 NONAME ; public: int __thiscall CMidiClientUtility::VolumeL(void)const 
	?MaxPolyphonyL@CMidiClientUtility@@QBEHXZ @ 78 NONAME ; int CMidiClientUtility::MaxPolyphonyL(void) const
	?OpenFile@CMidiClientUtility@@QAEXABVRFile@@@Z @ 79 NONAME ; void CMidiClientUtility::OpenFile(class RFile const &)
	?GetDRMCustomCommand@CMidiClientUtility@@QAEPAVMMMFDRMCustomCommand@@XZ @ 80 NONAME ; class MMMFDRMCustomCommand * CMidiClientUtility::GetDRMCustomCommand(void)
	?OpenFile@CMidiClientUtility@@QAEXABVTMMSource@@@Z @ 81 NONAME ; void CMidiClientUtility::OpenFile(class TMMSource const &)
	?NewL@CMidiClientUtility@@SAPAV1@AAVMMidiClientUtilityObserver@@HHH@Z @ 82 NONAME ; class CMidiClientUtility * CMidiClientUtility::NewL(class MMidiClientUtilityObserver &, int, int, int)



	


